==> ugene_34.0%2Bdfsg.orig.tar.xz: ugene-34.0/src/plugins/GUITestBase/src/tests/common_scenarios/sequence_edit/GTTestsSequenceEditMode.h <==
/**
 * UGENE - Integrated Bioinformatics Tools.
 * Copyright (C) 2008-2020 UniPro <ugene@unipro.ru>
 * http://ugene.net
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301, USA.
 */

#ifndef _U2_GUI_TEST_SEQUENCE_EDIT_MODE_H_
#define _U2_GUI_TEST_SEQUENCE_EDIT_MODE_H_

#include <U2Test/UGUITestBase.h>

namespace U2 {

namespace GUITest_common_scenarios_sequence_edit_mode {
#undef GUI_TEST_SUITE
#define GUI_TEST_SUITE "GUITest_common_scenarios_sequence_edit_mode"

GUI_TEST_CLASS_DECLARATION(without_anns_test_0001)
GUI_TEST_CLASS_DECLARATION(without_anns_test_0002)
GUI_TEST_CLASS_DECLARATION(without_anns_test_0003)
GUI_TEST_CLASS_DECLARATION(without_anns_test_0004)
GUI_TEST_CLASS_DECLARATION(with_anns_test_0001)
GUI_TEST_CLASS_DECLARATION(with_anns_test_0002)
GUI_TEST_CLASS_DECLARATION(with_anns_test_0003)
GUI_TEST_CLASS_DECLARATION(with_anns_test_0004)
GUI_TEST_CLASS_DECLARATION(with_anns_test_0005)
GUI_TEST_CLASS_DECLARATION(with_anns_test_0006)
GUI_TEST_CLASS_DECLARATION(with_anns_test_0007)
GUI_TEST_CLASS_DECLARATION(with_anns_test_0008)

#undef GUI_TEST_SUITE
}

} //namespace

#endif

==> ugene_40.1%2Bdfsg.orig.tar.xz: ugene-40.1/src/plugins/GUITestBase/src/tests/common_scenarios/sequence_edit/GTTestsSequenceEditMode.h <==
/**
 * UGENE - Integrated Bioinformatics Tools.
 * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
 * http://ugene.net
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301, USA.
 */

#ifndef _U2_GUI_TEST_SEQUENCE_EDIT_MODE_H_
#define _U2_GUI_TEST_SEQUENCE_EDIT_MODE_H_

#include <harness/UGUITestBase.h>

namespace U2 {

namespace GUITest_common_scenarios_sequence_edit_mode {
#undef GUI_TEST_SUITE
#define GUI_TEST_SUITE "GUITest_common_scenarios_sequence_edit_mode"

GUI_TEST_CLASS_DECLARATION(without_anns_test_0001)
GUI_TEST_CLASS_DECLARATION(without_anns_test_0002)
GUI_TEST_CLASS_DECLARATION(without_anns_test_0003)
GUI_TEST_CLASS_DECLARATION(without_anns_test_0004)
GUI_TEST_CLASS_DECLARATION(with_anns_test_0001)
GUI_TEST_CLASS_DECLARATION(with_anns_test_0002)
GUI_TEST_CLASS_DECLARATION(with_anns_test_0003)
GUI_TEST_CLASS_DECLARATION(with_anns_test_0004)
GUI_TEST_CLASS_DECLARATION(with_anns_test_0005)
GUI_TEST_CLASS_DECLARATION(with_anns_test_0006)
GUI_TEST_CLASS_DECLARATION(with_anns_test_0007)
GUI_TEST_CLASS_DECLARATION(with_anns_test_0008)

#undef GUI_TEST_SUITE
}  // namespace GUITest_common_scenarios_sequence_edit_mode

}  // namespace U2

#endif
